@@ -14,7 +14,7 @@ use CPAN::Audit::Version;
 use CPAN::Audit::Query;
 use CPAN::Audit::DB;
 
-our $VERSION = '20240215.001';
+our $VERSION = '20240910.001';
 
 sub new {
 	my( $class, %params ) = @_;
@@ -26,7 +26,7 @@ sub new {
 
 	$self->_handle_exclude_file if $self->{exclude_file};
 
-	$self->{db}     //= CPAN::Audit::DB->db;
+	$self->{db} //= $self->_get_db(%args);
 
 	$self->{filter}   = CPAN::Audit::Filter->new( exclude => $args{exclude} );
 	$self->{query}    = CPAN::Audit::Query->new( db => $self->{db} );
@@ -35,6 +35,36 @@ sub new {
 	return $self;
 }
 
+sub _get_db {
+	my( $self, %params ) = @_;
+
+	if ( $params{'json_db'} ) {
+		my $data = do {
+			local $/;
+			open my($fh), '<:raw', $params{'json_db'}
+				or die "could not read file <$params{json_db}>\n";
+			<$fh>;
+		};
+		state $rc = require JSON;
+
+		my $decoded = eval { JSON::decode_json($data) };
+		die "could not decode JSON from <$params{json_db}>: @_\n" unless defined $decoded;
+		return $decoded;
+	}
+
+	my $rc = eval { require CPANSA::DB };
+	if ( $rc ) {
+		return CPANSA::DB->db;
+	}
+
+	$rc = eval { require CPAN::Audit::DB };
+	if ( $rc ) {
+		return CPAN::Audit::DB->db;
+	}
+
+	die "could not find a CPANSA database in CPANSA::DB or CPAN::Audit::DB\n";
+}
+
 sub _handle_exclude_file {
 	my( $self ) = @_;
 
